@@ -7,7 +7,7 @@
 #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 package Nile::Module::Home::Home;
 
-our $VERSION = '0.46';
+our $VERSION = '0.47';
 our $AUTHORITY = 'cpan:MEWSOFT';
 
 use Nile::Module; # automatically extends Nile::Module
@@ -56,6 +56,10 @@ sub home : GET Action {
     $app->cache->set("visitor_count", $app->cache->get("visitor_count") + 1, "1 year");
     $view->set("visitor_count", $app->cache->get("visitor_count"));
     
+	my $redis = $app->plugin->redis;
+	$redis->set("My Name"=>"Ahmed Amin Elsheshtawy Gouda");
+	say $redis->get("My Name");
+
     return $view->out();
 }
 #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
